pub enum SchedulerError {
Flow(Error),
UnexpectedTaggedResponse(Tagged<'static>),
UnexpectedByeResponse(Bye<'static>),
}Variants
Flow(Error)
Flow error.
UnexpectedTaggedResponse(Tagged<'static>)
Unexpected tag in command completion result.
The scheduler received a tag that cannot be matched to an active command. This could be due to a severe implementation error in the scheduler, the server, or anything in-between, really.
It’s better to halt the execution to avoid damage.
UnexpectedByeResponse(Bye<'static>)